import { html, LitElement } from '../web_modules/lit-element.js';
import scss from './slotted-modal.style.js';
import icons from './icons.js';

class SlottedModal extends LitElement {
  static get styles() {
    return scss;
  }

  static get properties() {
    return {
      open: {
        type: Boolean
      },
      handleClose: {
        attribute: false
      },
      zIndex: {
        attribute: 'z-index',
        type: String
      }
    };
  }

  constructor() {
    super();
    this.open = false;

    this.handleClose = () => {
      this.open = false;
    };
  }

  get cssVariables() {
    const variables = [];

    if (this.zIndex) {
      variables.push(`--slotted-modal__z-index: ${this.zIndex}`);
    }

    return variables.join('; ');
  }

  render() {
    return html`
      <div class="wrapper ${this.open ? 'wrapper--open' : 'wrapper--closed'}" style="${this.cssVariables}">
        <div class="content">
          <button
            class="close-btn"
            @click=${this.handleClose}
            aria-label="Close modal"
          >
            ${icons.close}
          </button>
          <slot></slot>
        </div>
      </div>
    `;
  }

}

if (!customElements.get('slotted-modal')) {
  customElements.define('slotted-modal', SlottedModal);
}

export default SlottedModal;