import { LitElement, html } from '../web_modules/lit-element.js';
import icons from './icons.js';
import scss from './styled-button.style.js';

class StyledButton extends LitElement {
  static get properties() {
    return {
      appearance: {
        type: String
      },
      icon: {
        type: String,
        reflect: true
      },
      tileIcon: {
        type: String,
        attribute: 'tile-icon'
      },
      iconFirst: {
        type: Boolean,
        attribute: 'icon-first'
      }
    };
  }

  static get styles() {
    return scss;
  }

  get cssClasses() {
    const classes = ['container'];

    if (icons[this.icon] || this.querySelector('[slot=icon]')) {
      classes.push('has-icon');
    }

    if (this.iconFirst) {
      classes.push('icon-first');
    }

    return classes;
  }

  render() {
    const classes = this.cssClasses.join(' ');
    let tileIcon = '';

    if (this.appearance && this.appearance.startsWith('button-tile') && this.tileIcon) {
      tileIcon = html`<div class="tile-icon"><img src="${this.tileIcon}" alt=""></div>`;
    }

    return html`
      <div class="${classes}">
        <div class="background"></div>
        ${tileIcon}
        <div class="label-container">
          <span class="label"><slot></slot><slot name="label"></slot></span>
          <span class="icon">${icons[this.icon] || html`<slot name="icon"></slot>`}</span>
        </div>
      </div>
    `;
  }

}

if (!customElements.get('styled-button')) {
  customElements.define('styled-button', StyledButton);
}

export default StyledButton;